@@ -4,9 +4,10 @@
 #'
 #' @param x Variable 1
 #' @param y Variable 2
-#' @param order Controls the level of quadrant partitioning.  Defualts to NULL to have data determine maximum partitions.  Setting a specific order will activate \code{overide=TRUE} from \link{partition.map}
+#' @param order Controls the level of quadrant partitioning.  Defualts to NULL to have data determine maximum partitions.  Setting a specific order will activate \code{override=TRUE} from \link{partition.map}
 #' @param degree Defaults to NULL to allow number of observations to be \code{degree} determinant.
 #' @param print.map  Displays partition mapping onto plot.  Defaults to TRUE.
+#' @return Returns the \code{"Correlation"} and \code{"Dependence"}
 #' @keywords dependence, correlation
 #' @author Fred Viole, OVVO Financial Systems
 #' @references Viole, F. and Nawrocki, D. (2013) "Nonlinear Nonparametric Statistics: Using Partial Moments"
@@ -36,26 +37,24 @@ VN.dep = function( x, y,order = NULL,
   dep.rhos = numeric(0)
 
   if(print.map==TRUE){
-    plot(x,y,col='blue',pch=20)
+    plot(x,y,col='blue',pch=20,cex.lab=2,xlab = "X",ylab="Y")
     abline(h=mean(y),v=mean(x),lwd=3,col='azure4')
-    points(reg.points[,1],reg.points[,2],pch=19,lwd=2,col='red')}
+    points(reg.points[,1],reg.points[,2],pch=15,lwd=2,col='red')}
 
 
-  max.part = min(nchar(partitioned_df$master_part))
-  part = nchar(partitioned_df$master_part)
+  max.part = min(nchar(partitioned_df$quadrant))
+  part = nchar(partitioned_df$quadrant)
 
-  partitioned_df[,'master_part']=ifelse(part>max.part,
-    substr(partitioned_df$master_part[part>max.part],1,nchar(partitioned_df$master_part[part>max.part])-1),partitioned_df$master_part)
 
   prior.partitioned_df=partitioned_df
 
-  prior.partitioned_df[,'master_part']=substr(prior.partitioned_df$master_part,1,nchar(prior.partitioned_df$master_part)-1)
+  prior.partitioned_df[,'quadrant']=substr(partitioned_df$quadrant,1,max.part)
 
 
-  for(item in unique(prior.partitioned_df$master_part)){
+  for(item in unique(prior.partitioned_df$quadrant)){
 
-      sub_x = prior.partitioned_df[prior.partitioned_df$master_part == item, 'x']
-      sub_y = prior.partitioned_df[prior.partitioned_df$master_part == item, 'y']
+      sub_x = prior.partitioned_df[prior.partitioned_df$quadrant == item, 'x']
+      sub_y = prior.partitioned_df[prior.partitioned_df$quadrant == item, 'y']
 
 
       clpm = c(clpm, Co.LPM(degree, mean(sub_x),mean(sub_y),sub_x,sub_y))
@@ -74,7 +73,15 @@ VN.dep = function( x, y,order = NULL,
 
   rownames(m) = c("Correlation","Dependence")
 
+  nonlin.cor = (sum(clpm) +sum(cupm) -sum(dlpm) -sum(dupm))/(sum(clpm)+sum(cupm)+sum(dlpm)+sum(dupm))
 
-  m
+  if(is.na(nonlin.cor)){nonlin.cor=0}
+
+  dep = sum(na.omit(dep.rhos))/length(na.omit(dep.rhos))
+
+  if(is.na(dep)){dep=0}
+
+
+  return(list("Correlation"=nonlin.cor,"Dependence"= dep ))
 
 }
